@@ -14,7 +14,7 @@ use DBIx::Class::Async::TxnGuard;
 use DBIx::Class::Async::ResultSet;
 use DBIx::Class::Async::Storage::DBI;
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 =head1 NAME
 
@@ -22,7 +22,7 @@ DBIx::Class::Async::Schema - Asynchronous schema for DBIx::Class::Async
 
 =head1 VERSION
 
-Version 0.30
+Version 0.31
 
 =cut
 
@@ -304,6 +304,62 @@ sub clone {
     }, ref $self;
 }
 
+=head2 deploy
+
+    my $future = $schema->deploy(\%sqlt_args?, $dir?);
+
+    $future->on_done(sub {
+        my $self = shift;
+        say "Schema deployed successfully.";
+    });
+
+=over 4
+
+=item Arguments: \%sqlt_args?, $dir?
+
+=item Return Value: L<Future> resolving to $self
+
+=back
+
+Asynchronously deploys the database schema.
+
+This is a non-blocking proxy for L<DBIx::Class::Schema/deploy>. The actual SQL
+translation (via L<SQL::Translator>) and DDL execution are performed in a
+background worker process to prevent the main event loop from stalling.
+
+The optional C<\%sqlt_args> are passed directly to the worker-side
+C<deploy> method. Common options include:
+
+=over 4
+
+=item * C<add_drop_table> - Prepends a C<DROP TABLE> statement for each table.
+
+=item * C<quote_identifiers> - Ensures database identifiers are correctly quoted.
+
+=back
+
+On success, the returned L<Future> resolves to the schema object (C<$self>),
+allowing for easy method chaining. On failure, the Future fails with the
+error message generated by the worker.
+
+=cut
+
+sub deploy {
+    my ($self, $sqlt_args, $dir) = @_;
+
+    return $self->{async_db}
+                ->deploy($sqlt_args, $dir)
+                ->then(sub {
+                    my ($res) = @_;
+
+                    if (ref $res eq 'HASH' && $res->{__error}) {
+                        return Future->fail($res->{__error});
+                    }
+
+                    return Future->done($self);
+                });
+}
+
 =head2 disconnect
 
     $schema->disconnect;
